@@ -208,7 +208,7 @@ def get_priority(case_dict):
 def get_link(topics):
     links = [topic['link'] for topic in topics]
     links = filter_empty_or_ignore_element(links)
-    return links[-1]
+    return links[-1] if links and len(links) > 0 else ''
 
 
 def gen_testcase_title(topics):
